@@ -1,3 +1,4 @@
+from bergen.schema import Template
 from bergen.wards.graphql.subscription import SubscriptionGraphQLWard
 from bergen.registries.arnheim import get_current_arnheim
 import asyncio
@@ -78,10 +79,6 @@ class AsyncPodHandler:
                 pass
 
 
-
-
-        
-
     async def kill(self):
         await asyncio.sleep(0.01)
         logger.info("Closed Connection")
@@ -89,17 +86,17 @@ class AsyncPodHandler:
 
 class ProvisionHandler:
 
-    def __init__(self, nodeModel, ward: SubscriptionGraphQLWard, provider="vart") -> None:
+    def __init__(self, nodeModel, ward: SubscriptionGraphQLWard, template: Template = None) -> None:
         super().__init__()
         self._pod = None
         self._ward = ward
-        self._provider = provider
+        self._template = template
         self._node = nodeModel
 
     async def __aenter__(self):
-        from arnheim.constants import PROVIDE_GQL
+        from bergen.constants import PROVIDE_GQL
 
-        async for item in PROVIDE_GQL.subscribe(self._ward, variables={"node": self._node.id, "selector": {"provider": self._provider, "kwargs": {"volunteer": 2}}, "reference": str(uuid.uuid4())}):
+        async for item in PROVIDE_GQL.subscribe(self._ward, variables={"node": self._node.id, "selector": {"template": self.template.id, "kwargs": {"volunteer": 2}}, "reference": str(uuid.uuid4())}):
             if item.pod.status == "ACTIVE":
                 self._provisionreference = item.reference 
                 self._pod = AsyncPodHandler(self, self._ward, self._node, item.pod)
@@ -146,7 +143,7 @@ class NodeExtender(BaseExtender):
         loop.close()
         return result
 
-    def __call__(self, inputs: dict, provider="vart", stream=False):
+    def __call__(self, inputs: dict, template: Template = None, stream=False):
         """Call this method to notify all subscriptions in the group.
         This method can be called from both synchronous and asynchronous
         contexts. If you call it from the asynchronous context then you
@@ -165,12 +162,10 @@ class NodeExtender(BaseExtender):
             pass
         else:
             if event_loop.is_running():
-                if stream: return self.__call__as_stream(inputs, provider)
-                return self.__call_async(inputs, provider)
-        
-
+                if stream: return self.__call__as_stream(inputs, template)
+                return self.__call_async(inputs, template)
             
-        return self.__call_sync(inputs, provider)
+        return self.__call_sync(inputs, template)
 
     def provide(self, provider = "vart"):
         ward = get_current_arnheim().getWard()
